@@ -15,10 +15,22 @@ def delete(key):
 def set(key, value, timeout=None):
     _cache_dict[key] = value
 
+def set_many(vals_by_key, timeout=None):
+    for key, value in vals_by_key.items():
+        _cache_dict[key] = value
+
 def get(key):
     return _cache_dict.get(key)
 
-def incr(self, key, delta=1):
+def get_many(keys):
+    result = {}
+
+    for key in keys:
+        result[key] = _cache_dict.get(key)
+
+    return result
+
+def incr(key, delta=1):
     if not key in _cache_dict:
         _cache_dict[key] = 0
     _cache_dict[key] += delta
